Chapter

Struct Chapter 

pub struct Chapter { /* private fields */ }
A single chapter information

Implementations

Source

impl Chapter

pub fn title_id(&self) -> u64

Title ID

pub fn chapter_id(&self) -> u64

Chapter ID

pub fn title(&self) -> &str

Chapter title

pub fn thumbnail(&self) -> &str

Chapter thumbnail URL

pub fn published_at(&self) -> i64

Chapter published/start UNIX timestamp

pub fn viewed(&self) -> bool

Is the chapter already viewed?

pub fn vertical_only(&self) -> bool

Is the chapter can be read in vertical mode only?

pub fn free(&self) -> bool

Is the chapter can be read for free?

pub fn horizontal_only(&self) -> bool

Is the chapter can be read in horizontal mode only?

pub fn view_count(&self) -> u64

Chapter view count

pub fn comment_count(&self) -> u64

Chapter comment count

Source

impl Chapter

pub fn subtitle(&self) -> &str

Returns the value of subtitle, or the default value if subtitle is unset.

pub fn end_at(&self) -> i64

Returns the value of end_at, or the default value if end_at is unset.

pub fn ticket_end_at(&self) -> i64

Returns the value of ticket_end_at, or the default value if ticket_end_at is unset.

pub fn position(&self) -> ChapterPosition

Returns the enum value of position, or the default if the field is set to an invalid enum value.

pub fn set_position(&mut self, value: ChapterPosition)

Sets position to the provided enum value.

Source

impl Chapter

pub fn is_free(&self) -> bool

Can this chapter be read for free?

pub fn is_ticketed(&self) -> bool

Can this chapter be read with ticket?

pub fn default_view_mode(&self) -> &'static str

Get the default viewing mode

pub fn as_chapter_title(&self) -> String

Format the chapter title and subtitle into a single string.

If the subtitle is None, the title will be returned as is.