pub struct ChapterGroup { /* private fields */ }Expand description
A group of chapters
Implementations
Sourceimpl ChapterGroup
impl ChapterGroup
Sourcepub fn first_chapters(&self) -> &[Chapter]
pub fn first_chapters(&self) -> &[Chapter]
The first chapters list, all of them should be free to read
Sourcepub fn mid_chapters(&self) -> &[Chapter]
pub fn mid_chapters(&self) -> &[Chapter]
The mid chapters list, this chapter is locked behind subscriptions or tickets
Sourcepub fn last_chapters(&self) -> &[Chapter]
pub fn last_chapters(&self) -> &[Chapter]
The last chapters list, all of them should be free to read
Sourceimpl ChapterGroup
impl ChapterGroup
Sourcepub fn first_chapters_mut(&mut self) -> &mut Vec<Chapter>
pub fn first_chapters_mut(&mut self) -> &mut Vec<Chapter>
Get the mutable reference to first chapters
Sourcepub fn mid_chapters_mut(&mut self) -> &mut Vec<Chapter>
pub fn mid_chapters_mut(&mut self) -> &mut Vec<Chapter>
Get the mutable reference to mid chapters
Sourcepub fn last_chapters_mut(&mut self) -> &mut Vec<Chapter>
pub fn last_chapters_mut(&mut self) -> &mut Vec<Chapter>
Get the mutable reference to last chapters