pub struct ErrorResponse { /* private fields */ }Expand description
An error response.
Implementations
Sourceimpl ErrorResponse
impl ErrorResponse
Sourcepub fn english_popup(&self) -> Option<&PopupMessage>
pub fn english_popup(&self) -> Option<&PopupMessage>
English popup message
Sourcepub fn spanish_popup(&self) -> Option<&PopupMessage>
pub fn spanish_popup(&self) -> Option<&PopupMessage>
Spanish popup message
Sourcepub fn other_popups(&self) -> &[PopupMessage]
pub fn other_popups(&self) -> &[PopupMessage]
Array of other popup messages
Sourceimpl ErrorResponse
impl ErrorResponse
Sourcepub fn action(&self) -> ErrorAction
pub fn action(&self) -> ErrorAction
Returns the enum value of action, or the default if the field is set to an invalid enum value.
Sourcepub fn set_action(&mut self, value: ErrorAction)
pub fn set_action(&mut self, value: ErrorAction)
Sets action to the provided enum value.
Sourcepub fn debug_message(&self) -> &str
pub fn debug_message(&self) -> &str
Returns the value of debug_message, or the default value if debug_message is unset.