pub enum SuccessOrError {
Success(Box<SuccessResponse>),
Error(Box<ErrorResponse>),
}Expand description
A success or error response enum
This is used like oneOf in Protobuf so only one of them will be available.
Variants
Success(Box<SuccessResponse>)
A Box-ed SuccessResponse
Depending on the API request, only some of them would be available to be used.
Error(Box<ErrorResponse>)
A Box-ed ErrorResponse
Implementations
Sourceimpl SuccessOrError
impl SuccessOrError
Sourcepub fn merge(
field: &mut Option<SuccessOrError>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<SuccessOrError>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.