pub enum ChapterPosition {
Middle = 0,
First = 1,
Last = 2,
Unrecognized = -1,
}Expand description
Chapter position in the series chapters list group
This is a custom enum that does not exist originally in the API. Made to make it easier to understand the position of the chapter in the series.
Variants
Middle = 0
Chapter located in the middle of the chapter list (usually need subs or tickets)
First = 1
Chapter located in first chapter list (usually free)
Last = 2
Chapter located in last chapter list (usually free)
Unrecognized = -1
An error has occurred.
Implementations
Sourceimpl ChapterPosition
impl ChapterPosition
Sourcepub fn from_i32(value: i32) -> Option<ChapterPosition>
👎Deprecated: User the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ChapterPosition>
Converts an i32 value to the corresponding ChapterPosition enum variant, returning the ChapterPosition::Unrecognized variant if it doesn’t match any variant.